.. _models:

========================================
Models subpackage :mod:`melusine.models`
========================================

TODO : ADD DESCRIPTION OF THE SUBPACKAGE

------------------
List of submodules
------------------
.. contents::
   :local:


.. _neural_architectures:

NeuralArchitectures :mod:`melusine.models.neural_architectures`
---------------------------------------------------------------

.. automodule:: melusine.models.neural_architectures
   :members:
   :undoc-members:
   :show-inheritance:


.. _train:

Train :mod:`melusine.models.train`
----------------------------------

.. automodule:: melusine.models.train
  :members:
  :undoc-members:
  :show-inheritance:
